@@ -23,7 +23,6 @@
 #include <language/duchain/duchainutils.h>
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KAboutData>
 #include <KLocalizedString>
 #include <QVariant>
@@ -162,3 +161,5 @@ void PhpUnitProvider::processTestCaseDeclaration(Declaration* d)
 }
 
 #include "phpunitprovider.moc"
+
+#include "moc_phpunitprovider.cpp"
